#!/usr/bin/env python3

class Curso:

    def __init__(self, name, duration, link):
        self.name = name
        self.duration = duration
        self.link = link

    def __repr__(self):

        return f"{self.name} [{self.duration} horas] ({self.link})"

courses = [
    Curso("Introducción a Linux", 15, "https://hack4u.io/cursos/introduccion-a-linux/"),
    Curso("Personalización de entorno en Linux", 3, "https://hack4u.io/cursos/personalizacion-de-entorno-en-linux/"),
    Curso("Python ofensivo", 35, "https://hack4u.io/cursos/python-ofensivo/"),
    Curso("Introducción al Hacking", 53, "https://hack4u.io/cursos/introduccion-al-hacking/")
    ]

def list_courses():
    for course in courses:
        print(course)

def search_course_by_name(name):

    for course in courses:

        if course.name == name:
            return course

    return None





from setuptools import setup, find_packages

# Leer el contenido del archivo README.md
with open("README.md", "r", encoding="utf-8") as fh:
	log_description = fh.read()

setup(
	name="hack4u_sammy-ulfh",
	version="0.1.0",
	packages=find_packages(),
	install_requires=[],
	author="Sammy-ulfh",
	description="Una biblioteca para consultar cursos de hack4u.",
	long_description=log_description,
	long_description_content_type="text/markdown",
	url="https://hack4u.io",
)
